@@ -69,31 +69,31 @@ SUSE2Config::SUSE2Config(TDEConfig *config, TQWidget *parent)
     toggleIconSettings(m_dialog->useTitleProps->isChecked());
 
     // setup the connections
-    connect(m_dialog->titleAlign, SIGNAL(clicked(int)), SIGNAL(changed()));
-    connect(m_dialog->roundCorners, SIGNAL(clicked(int)), SIGNAL(changed()));
-    connect(m_dialog->menuClose, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(m_dialog->titleShadow, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(m_dialog->addSpace, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-    connect(m_dialog->titlebarStyle, SIGNAL(activated(int)), SIGNAL(changed()));
+    connect(m_dialog->titleAlign, TQ_SIGNAL(clicked(int)), TQ_SIGNAL(changed()));
+    connect(m_dialog->roundCorners, TQ_SIGNAL(clicked(int)), TQ_SIGNAL(changed()));
+    connect(m_dialog->menuClose, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(m_dialog->titleShadow, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(m_dialog->addSpace, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
+    connect(m_dialog->titlebarStyle, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
 
-    connect(m_dialog->buttonType, SIGNAL(activated(int)), SIGNAL(changed()));
-    connect(m_dialog->customColors, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(m_dialog->useTitleProps, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(m_dialog->animateButtons, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(m_dialog->redCloseButton, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(m_dialog->iconSize, SIGNAL(valueChanged(int)), SIGNAL(changed()));
-    connect(m_dialog->customIconColors, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(m_dialog->activeFgColor, SIGNAL(changed(const TQColor &)), SIGNAL(changed()));
-    connect(m_dialog->activeBgColor, SIGNAL(changed(const TQColor &)), SIGNAL(changed()));
-    connect(m_dialog->inactiveFgColor, SIGNAL(changed(const TQColor &)), SIGNAL(changed()));
-    connect(m_dialog->inactiveBgColor, SIGNAL(changed(const TQColor &)), SIGNAL(changed()));
-    connect(m_dialog->iconShadow, SIGNAL(toggled(bool)), SIGNAL(changed()));
+    connect(m_dialog->buttonType, TQ_SIGNAL(activated(int)), TQ_SIGNAL(changed()));
+    connect(m_dialog->customColors, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(m_dialog->useTitleProps, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(m_dialog->animateButtons, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(m_dialog->redCloseButton, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(m_dialog->iconSize, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
+    connect(m_dialog->customIconColors, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(m_dialog->activeFgColor, TQ_SIGNAL(changed(const TQColor &)), TQ_SIGNAL(changed()));
+    connect(m_dialog->activeBgColor, TQ_SIGNAL(changed(const TQColor &)), TQ_SIGNAL(changed()));
+    connect(m_dialog->inactiveFgColor, TQ_SIGNAL(changed(const TQColor &)), TQ_SIGNAL(changed()));
+    connect(m_dialog->inactiveBgColor, TQ_SIGNAL(changed(const TQColor &)), TQ_SIGNAL(changed()));
+    connect(m_dialog->iconShadow, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
 
-    connect(m_dialog->titleBarLogo, SIGNAL(toggled(bool)), SIGNAL(changed()));
-    connect(m_dialog->titleBarLogoOffset, SIGNAL(valueChanged(int)), SIGNAL(changed()));
+    connect(m_dialog->titleBarLogo, TQ_SIGNAL(toggled(bool)), TQ_SIGNAL(changed()));
+    connect(m_dialog->titleBarLogoOffset, TQ_SIGNAL(valueChanged(int)), TQ_SIGNAL(changed()));
 
-    connect(m_dialog->useTitleProps, SIGNAL(toggled(bool)), SLOT(toggleIconSettings(bool)));
-    connect(m_dialog->selectButton, SIGNAL(clicked()), SLOT(selectImage()));
+    connect(m_dialog->useTitleProps, TQ_SIGNAL(toggled(bool)), TQ_SLOT(toggleIconSettings(bool)));
+    connect(m_dialog->selectButton, TQ_SIGNAL(clicked()), TQ_SLOT(selectImage()));
 }
 
 SUSE2Config::~SUSE2Config()
